==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/yrtietftetypes/rev20160320/yrtietftetypes/tunnelpathsrlgs/tunnelpathsrlgs/style/DefaultValues.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.style;

import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.RouteExcludeSrlg;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.Srlg;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.Style;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of values.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultValues extends InnerModelObject implements Values {
    protected Class<? extends RouteExcludeSrlg> usage;
    protected List<Srlg> values;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Class<? extends RouteExcludeSrlg> usage() {
        return usage;
    }

    @Override
    public List<Srlg> values() {
        return values;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void usage(Class<? extends RouteExcludeSrlg> usage) {
        valueLeafFlags.set(LeafIdentifier.USAGE.getLeafIndex());
        this.usage = usage;
    }

    @Override
    public void values(List<Srlg> values) {
        valueLeafFlags.set(LeafIdentifier.VALUES.getLeafIndex());
        this.values = values;
    }

    @Override
    public void addToValues(Srlg addTo) {
        if (values == null) {
            values = new ArrayList<>();
        }
        values.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(usage, values, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultValues) {
            DefaultValues other = (DefaultValues) obj;
            return
                Objects.equals(usage, other.usage) &&
                Objects.equals(values, other.values) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("usage=" + usage)
            .add("values=" + values)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultValues.
     */
    public DefaultValues() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetypes/rev20160320/yrtietftetypes/tunnelpathsrlgs/tunnelpathsrlgs/style/DefaultValues.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.style;

import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.RouteExcludeSrlg;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.Srlg;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.Style;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of values.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultValues extends InnerModelObject implements Values {
    protected Class<? extends RouteExcludeSrlg> usage;
    protected List<Srlg> values;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Class<? extends RouteExcludeSrlg> usage() {
        return usage;
    }

    @Override
    public List<Srlg> values() {
        return values;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void usage(Class<? extends RouteExcludeSrlg> usage) {
        valueLeafFlags.set(LeafIdentifier.USAGE.getLeafIndex());
        this.usage = usage;
    }

    @Override
    public void values(List<Srlg> values) {
        valueLeafFlags.set(LeafIdentifier.VALUES.getLeafIndex());
        this.values = values;
    }

    @Override
    public void addToValues(Srlg addTo) {
        if (values == null) {
            values = new ArrayList<>();
        }
        values.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(usage, values, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultValues) {
            DefaultValues other = (DefaultValues) obj;
            return
                Objects.deepEquals(usage, other.usage) &&
                Objects.deepEquals(values, other.values) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("usage=" + usage)
            .add("values=" + values)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultValues.
     */
    public DefaultValues() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
